@@ -9,13 +9,15 @@
     :license: MIT, see LICENSE for more details.
 """
 from abc import ABC, abstractmethod
+from typing import Optional, Any
 
-from pip_services3_commons.refer import IReferenceable, Descriptor
-
-from .LogLevel import LogLevel
-from .ILogger import ILogger
-from .LogLevelConverter import LogLevelConverter
+from pip_services3_commons.config import ConfigParams
 from pip_services3_commons.config.IReconfigurable import IReconfigurable
+from pip_services3_commons.refer import IReferenceable, Descriptor, IReferences
+
+from .ILogger import ILogger
+from .LogLevel import LogLevel
+from .LogLevelConverter import LogLevelConverter
 
 
 class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
@@ -33,10 +35,12 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
     ### References ###
         - `*:context-info:*:*:1.0`     (optional) :class:`ContextInfo <pip_services3_components.info.ContextInfo.ContextInfo>` to detect the context id and specify counters source
     """
-    _level = LogLevel.Info
-    _source = None
 
-    def configure(self, config):
+    def __init__(self):
+        self._level = LogLevel.Info
+        self._source: str = None
+
+    def configure(self, config: ConfigParams):
         """
         Configures component by passing configuration parameters.
 
@@ -45,7 +49,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         self._level = LogLevelConverter.to_log_level(config.get_as_object("level"))
         self._source = config.get_as_string_with_default("source", self._source)
 
-    def set_references(self, references):
+    def set_references(self, references: IReferences):
         """
         Sets references to dependent components.
 
@@ -55,7 +59,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         if context_info is not None and self._source is None:
             self._source = context_info.name
 
-    def get_level(self):
+    def get_level(self) -> LogLevel:
         """
         Gets the maximum log level. Messages with higher log level are filtered out.
 
@@ -63,7 +67,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         return self._level
 
-    def set_level(self, level):
+    def set_level(self, level: LogLevel):
         """
         Set the maximum log level.
 
@@ -71,8 +75,25 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._level = level
 
+    def get_source(self) -> str:
+        """
+        Gets the source (context) name.
+
+        :return: the source (context) name.
+        """
+        return self._source
+
+    def set_source(self, value: str):
+        """
+        Sets the source (context) name.
+
+        :param value: a new source (context) name.
+        """
+        self._source = value
+
     @abstractmethod
-    def _write(self, level, correlation_id, error, message):
+    def _write(self, level: LogLevel, correlation_id: Optional[str], error: Optional[Exception],
+               message: Optional[str]):
         """
         Writes a log message to the logger destination.
 
@@ -86,7 +107,8 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         raise NotImplementedError('Method from abstract implementation')
 
-    def _format_and_write(self, level, correlation_id, error, message, *args, **kwargs):
+    def _format_and_write(self, level: LogLevel, correlation_id: Optional[str], error: Exception, message: str,
+                          *args: Any, **kwargs: Any):
         """
         Formats the log message and writes it to the logger destination.
 
@@ -110,7 +132,9 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
             message = message % (*args, *kwargs)
         self._write(level, correlation_id, error, message)
 
-    def log(self, level, correlation_id, error, message, *args, **kwargs):
+    def log(self, level: LogLevel, correlation_id: Optional[str], error: Optional[Exception], message: Optional[str],
+            *args: Any,
+            **kwargs: Any):
         """
         Logs a message at specified log level.
 
@@ -128,7 +152,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(level, correlation_id, error, message, *args, **kwargs)
 
-    def fatal(self, correlation_id, error, message, *args, **kwargs):
+    def fatal(self, correlation_id: Optional[str], error: Exception, message: str, *args: Any, **kwargs: Any):
         """
         Logs fatal (unrecoverable) message that caused the process to crash.
 
@@ -144,7 +168,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Fatal, correlation_id, error, message, *args, **kwargs)
 
-    def error(self, correlation_id, error, message, *args, **kwargs):
+    def error(self, correlation_id: Optional[str], error: Exception, message: str, *args: Any, **kwargs: Any):
         """
         Logs recoverable application error.
 
@@ -160,7 +184,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Error, correlation_id, error, message, *args, **kwargs)
 
-    def warn(self, correlation_id, message, *args, **kwargs):
+    def warn(self, correlation_id: Optional[str], message: str, *args: Any, **kwargs: Any):
         """
         Logs a warning that may or may not have a negative impact.
 
@@ -174,7 +198,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Warn, correlation_id, None, message, *args, **kwargs)
 
-    def info(self, correlation_id, message, *args, **kwargs):
+    def info(self, correlation_id: Optional[str], message: str, *args: Any, **kwargs: Any):
         """
         Logs an important information message
 
@@ -188,7 +212,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Info, correlation_id, None, message, *args, **kwargs)
 
-    def debug(self, correlation_id, message, *args, **kwargs):
+    def debug(self, correlation_id: Optional[str], message: str, *args: Any, **kwargs: Any):
         """
         Logs a high-level debug information for troubleshooting.
 
@@ -202,7 +226,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Debug, correlation_id, None, message, *args, **kwargs)
 
-    def trace(self, correlation_id, message, *args, **kwargs):
+    def trace(self, correlation_id: Optional[str], message: str, *args: Any, **kwargs: Any):
         """
         Logs a low-level debug information for troubleshooting.
 
@@ -216,7 +240,7 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         self._format_and_write(LogLevel.Trace, correlation_id, None, message, *args, **kwargs)
 
-    def _compose_error(self, error):
+    def _compose_error(self, error: Exception) -> str:
         """
         Composes an human-readable error description
 
@@ -225,15 +249,15 @@ class Logger(ILogger, IReconfigurable, IReferenceable, ABC):
         """
         builder = ''
 
-        builder += error.message
+        builder += str(error) if not hasattr(error, 'message') else error.message
 
         app_error = error
-        if app_error.cause:
+        if hasattr(app_error, 'cause'):
             builder += ' Cause by: '
             builder += str(app_error.cause)
 
-        if error.stack_trace:
-            builder += ' Stack trace '
+        if hasattr(error, 'stack_trace'):
+            builder += ' Stack trace: '
             builder += error.stack_trace
 
         return builder
